@@ -1,8 +1,8 @@
-"pscoast" <-
-function(cmd, file=options("gmt.file"))
+`pscoast` <-
+function(cmd, file=getOption("gmt.file"))
 {
-  if(is.list(file)) file <- unlist(file)[1]
   if(is.null(file)) stop("Please pass a valid 'file' argument, or run gmt(file=\"myfile\").")
+  owd <- setwd(dirname(file)); on.exit(setwd(owd))
 
   gmt.system(paste("pscoast",cmd), file=file)
 
